==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/AnnotationLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let AnnotationLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnnotationLayerDescriptionMetadata extends Base {
        static b(a) {
            if (AnnotationLayerDescriptionMetadata.a == null) {
                AnnotationLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnnotationLayerDescriptionMetadata.c(AnnotationLayerDescriptionMetadata.a);
            }
            if (a.j(AnnotationLayerDescriptionMetadata.a)) {
                return;
            }
            a.y(AnnotationLayerDescriptionMetadata.a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("UseIndex", "Boolean");
            a.item("UseLegend", "Boolean");
            a.item("CursorPosition", "Point");
            a.item("IsDefaultCrosshairDisabled", "Boolean");
            a.item("ShouldRenderAsOverlay", "Boolean");
        }
        static d(a) {
            AnnotationLayerDescriptionMetadata.b(a);
            a.z("AnnotationLayer", AnnotationLayerDescriptionMetadata.a);
        }
    }
    AnnotationLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(AnnotationLayerDescriptionMetadata, 'AnnotationLayerDescriptionMetadata');
    AnnotationLayerDescriptionMetadata.a = null;
    return AnnotationLayerDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AnnotationLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let AnnotationLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnnotationLayerDescriptionMetadata extends Base {
        static b(a) {
            if (AnnotationLayerDescriptionMetadata.a == null) {
                AnnotationLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnnotationLayerDescriptionMetadata.c(AnnotationLayerDescriptionMetadata.a);
            }
            if (a.k(AnnotationLayerDescriptionMetadata.a)) {
                return;
            }
            a.aa(AnnotationLayerDescriptionMetadata.a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("UseIndex", "Boolean");
            a.item("UseLegend", "Boolean");
            a.item("CursorPosition", "Point");
            a.item("IsDefaultCrosshairDisabled", "Boolean");
            a.item("ShouldRenderAsOverlay", "Boolean");
        }
        static d(a) {
            AnnotationLayerDescriptionMetadata.b(a);
            a.ab("AnnotationLayer", AnnotationLayerDescriptionMetadata.a);
        }
    }
    AnnotationLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(AnnotationLayerDescriptionMetadata, 'AnnotationLayerDescriptionMetadata');
    AnnotationLayerDescriptionMetadata.a = null;
    return AnnotationLayerDescriptionMetadata;
})();
